# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-07-21 18:22
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('directmessages', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='message',
            managers=[
            ],
        ),
        migrations.RemoveField(
            model_name='message',
            name='parent_msg',
        ),
        migrations.AlterField(
            model_name='message',
            name='recipient',
            field=models.ForeignKey(default=0, on_delete=django.db.models.deletion.CASCADE, related_name='received_dm', to=settings.AUTH_USER_MODEL, verbose_name='Recipient'),
            preserve_default=False,
        ),
    ]
